# /polysquarecmakelinter/__init__.py
#
# Entry point when loading module
#
# See LICENCE.md for Copyright information
"""Entry point when loading module."""
